@@ -499,7 +499,7 @@ class Ui_MainWindow(object):
                     self.button.setMaximumSize(40, 40)
                     self.button.clicked.connect(lambda checked, name=x: self.process_custom(name))
                     self.button.setIconSize(QtCore.QSize(40, 40))
-                    self.button.setIcon(QtGui.QIcon(self.location + "/images/custom.svg"))
+                    self.button.setIcon(QtGui.QIcon(self.location + "/images/Custom.svg"))
                     self.horizontalLayout2.addWidget(self.button)
                     self.horizontalLayout2.addWidget(self.button, 0, QtCore.Qt.AlignLeft)
         f.close()
@@ -775,7 +775,7 @@ class Ui_MainWindow(object):
                         self.button.setMaximumSize(40, 40)
                         self.button.clicked.connect(lambda checked, name=x: self.process_custom(name))
                         self.button.setIconSize(QtCore.QSize(40, 40))
-                        self.button.setIcon(QtGui.QIcon(self.location + "/images/custom.svg"))
+                        self.button.setIcon(QtGui.QIcon(self.location + "/images/Custom.svg"))
                         self.horizontalLayout2.addWidget(self.button)
                         self.horizontalLayout2.addWidget(self.button, 0, QtCore.Qt.AlignLeft)
             f.close()
@@ -1644,6 +1644,4 @@ class Ui_MainWindow(object):
                 self.slider_widget.setOrientation(QtCore.Qt.Horizontal)
                 self.slider_widget.valueChanged.connect(self.blend)
         except:
-            return
-
-        # additional image is now held in other_image attribute
+            return
\ No newline at end of file
